//@line 36 "/builds/tinderbox/Tb-Mozilla1.8.0-l10n-Release/Linux_2.4.18-14_Depend/mozilla/mail/locales/../../../l10n/es-AR/mail/all-l10n.js"

//@line 38 "/builds/tinderbox/Tb-Mozilla1.8.0-l10n-Release/Linux_2.4.18-14_Depend/mozilla/mail/locales/../../../l10n/es-AR/mail/all-l10n.js"

pref("general.useragent.locale", "es-AR");


